@@ -2,7 +2,7 @@ package Shipwright;
 
 use warnings;
 use strict;
-use version; our $VERSION = qv('2.4.1');
+use version; our $VERSION = qv('2.4.2');
 
 use base qw/Class::Accessor::Fast/;
 
@@ -12,6 +12,20 @@ use Shipwright::Logger;
 use Shipwright::Util;
 use File::Spec::Functions qw/catfile tmpdir/;
 
+$ENV{SHIPWRIGHT_MAKE} ||= 'make';
+$ENV{SHIPWRIGHT_SVK} ||= 'svk';
+$ENV{SHIPWRIGHT_SVN} ||= 'svn';
+$ENV{SHIPWRIGHT_GIT} ||= 'git';
+$ENV{SHIPWRIGHT_LWP_TIMEOUT} ||= 1200;
+
+$ENV{PERL_MM_USE_DEFAULT} = 1; # always true
+
+# FTP_PASSIVE is true by default,
+# since many sites use this nowadays.
+unless ( defined $ENV{FTP_PASSIVE} ) {
+    $ENV{FTP_PASSIVE} = 1;
+}
+
 sub new {
     my $class = shift;
 
